package openapi

import (
	"time"

	"github.com/go-openapi/strfmt"
)

// DateTimeBuilder is used to build datetime
// Use default UTC location
type DateTimeBuilder struct {
	data time.Time
}

func NewDateTimeBuilder() *DateTimeBuilder {
	return &DateTimeBuilder{
		data: time.Now().UTC(),
	}
}

// Add adds duration to datetime
func (d *DateTimeBuilder) Add(t time.Duration) *DateTimeBuilder {
	d.data = d.data.Add(t)
	return d
}

// AddSec adds sec seconds to datetime
func (d *DateTimeBuilder) AddSec(sec int) *DateTimeBuilder {
	d.Add(time.Duration(sec) * time.Second)
	return d
}

// Result returns the datetime built
func (d *DateTimeBuilder) Result() strfmt.DateTime {
	return strfmt.DateTime(d.ResultRaw())
}

// ResultPtr returns the datetime build in ptr
func (d *DateTimeBuilder) ResultPtr() *strfmt.DateTime {
	t := d.Result()
	return &t
}

// ResultRaw returns the time in raw time fmt
func (d *DateTimeBuilder) ResultRaw() time.Time {
	return d.data
}

// TimeNow returns the time now in datetime fmt
func TimeNow() strfmt.DateTime {
	return NewDateTimeBuilder().Result()
}

// TimeNowPtr returns time now in datetime ptr fmt
func TimeNowPtr() *strfmt.DateTime {
	return NewDateTimeBuilder().ResultPtr()
}
