package render

import (
	"encoding/json"
	"fmt"
	"reflect"
	"strings"
)

// render or dump struct in log msg

// Content is intended to print a struct on one line, especially for logging structs.
// Structs and Slice type are tested.
// Panics if struct cannot be turned to json, which is rare. Normal data struct there is no panic.
// In:
//	x : any struct or slice or map
func Content(x interface{}) string {
	// x is nil is handled by json pkg

	// dump things in json format
	bytes, err := json.Marshal(x)
	if err != nil {
		panic(fmt.Sprintf("bad struct %+v cannot marshall", x))
	}
	return trim(string(bytes))
}

// trim removes quotes in json str
func trim(s string) string {
	var b strings.Builder

	for _, char := range s {
		if char == '"' { //discard single quote rune
			continue
		}
		b.WriteRune(char)
	}
	return b.String()
}

// Type returns the type of x as string
// "nil" if nil
func Type(x interface{}) string {
	var tp string
	if x == nil {
		tp = "nil"
	} else {
		tp = reflect.TypeOf(x).String()
	}
	return tp
}
