// Copyright (c) 2020 NetApp, Inc. All rights reserved.

package uintid

import (
	"context"
)

type requestIdType string

const requestIdKey requestIdType = "requestKey"

// WithRqId returns a context which knows its request ID
func WithRqId(ctx context.Context, rqId uint64) context.Context {
	return context.WithValue(ctx, requestIdKey, rqId)
}

// ExtractRequestId returns a requestId associated with the context
func ExtractRequestId(ctx context.Context) uint64 {
	var ctxRqId uint64
	if ctx != nil {
		if ctxRqId, ok := ctx.Value(requestIdKey).(uint64); ok {
			return ctxRqId
		}
	}
	return ctxRqId
}
