package uintid

import "sync/atomic"

// UintID contains a uint64 and support atomic modification
type UintID struct {
	data uint64
}

// NewUintID returns a new UintID
func NewUintID() *UintID {
	return &UintID{data: 0}
}

// Get reads the id atomically
func (u *UintID) Get() uint64 {
	return atomic.LoadUint64(&u.data)
}

// Set set the id atomically
func (u *UintID) Set(x uint64) {
	atomic.StoreUint64(&u.data, x)
}

// Inc adds 1 to id atomically
func (u *UintID) Inc() uint64 {
	x := atomic.AddUint64(&u.data, 1)
	return x
}
