package wraphttp

import "net/http"

// WrapBeforeFunc is called before http handler serve the request and WrapAfterFunc is called after serve request.
// The intention of having this layout is that, we want to do something before handling the request
// and do another thing after the request.
//
// Note that the last return of WrapBeforeFunc can be anything, and it will be passed
// to the last param of AfterFunc.
//   One can pass the request number here to link inside before and after func which request is it.
//   One can pass the time stamp of the request starting time measured in BeforeFunc to AfterFunc
//      to collect request duration. etc

// WrapBeforeFunc is the function type that is called before handling http req
type WrapBeforeFunc func(w http.ResponseWriter, r *http.Request) (http.ResponseWriter, *http.Request, interface{})

// WrapBeforeFunc is the function type that is called before handling http req
type WrapAfterFunc func(w http.ResponseWriter, r *http.Request, x interface{}) (http.ResponseWriter, *http.Request)

// FuncPair is used to wrap a http request
//
type FuncPair struct {
	BeforeFunc WrapBeforeFunc
	AfterFunc  WrapAfterFunc
}
