// Copyright (c) 2020 NetApp, Inc. All rights reserved.

package wraphttp

import (
	"net/http"
)

// WrapWithOption applies option to wrap http handler
// see FuncPair to for detail
func WrapWithOption(next http.Handler, opt *Option) http.Handler {
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {

		// before serve http request, call before func in func pair
		resp := []interface{}{}

		for _, p := range opt.FuncPairs {
			wx, rx, x := p.BeforeFunc(w, r)
			w = wx
			r = rx
			resp = append(resp, x)
		}

		next.ServeHTTP(w, r)

		// after serve http request, call after func in func pair
		// and pass in the value returned by matching before func
		for idx, p := range opt.FuncPairs {
			x := resp[idx]
			w, r = p.AfterFunc(w, r, x)
		}
	})
}
