// Copyright (c) 2020 NetApp, Inc. All rights reserved.

package cvn

import (
	"context"

	"github.com/greenqloud/hyperscaler-network-client/models/common"

	"github.com/greenqloud/go-lib/log"
)

// TODO: Replace mock implementation with actual implementation.

// v1MockClient defines mock of CVN client
type v1MockClient struct {
}

// NewV1MockClient returns new instance of CVN mock client.
// Outputs:
//	- v1MockClient instance
//	- Error, if any.
func NewV1MockClient() (*v1MockClient, error) {
	return &v1MockClient{}, nil
}

// PreProcessClient performs region pre-processing on CVN V1 mock client
// Note: Implements models.HyperscalerClusterGetter interface on CVN V1 mock.
// Receiver:
//	c: CVN V1 mock client pointer.
func (c *v1MockClient) PreProcessClient(regionName string) {
	// Any pre-processing required for CVI client region / microzone-uuid
	log.Info("no pre-processing for mock client")
}

// GetClusters lists all clusters for the client.
// Note: Implements models.HyperscalerClusterGetter interface on CVN V1 mock client.
// Receiver:
//	c: CVN V1 mock client pointer.
// Outputs:
//	- Response from all clusters in models.HyperscalerGetResponse format.
//	- Error.
func (c *v1MockClient) GetClusters() ([]*common.HyperscalerGetResponse, error) {
	return c.GetClustersWithContext(context.Background())
}

// GetClustersWithContext gets the required cluster for the client using the provided context.
// Note: Implements models.HyperscalerClusterGetter interface on CVN V1 mock client.
// Receiver:
//	c: CVN V1 mock client pointer.
// Input:
//  ctx: context for the method
// Outputs:
//	- Response from all clusters in models.HyperscalerGetResponse format.
//	- Error.
func (c *v1MockClient) GetClustersWithContext(ctx context.Context) ([]*common.HyperscalerGetResponse, error) {
	dummyClusterModel1 := &common.HyperscalerGetResponse{
		Name: "dummy_name_1",
		UsageLimitMap: map[common.ResourceName]common.UsageLimit{
			common.TenancyResourceName: {
				Usage: 102,
				Limit: 500,
			},
		},
	}

	dummyClusterModel2 := &common.HyperscalerGetResponse{
		Name: "dummy_name_2",
		UsageLimitMap: map[common.ResourceName]common.UsageLimit{
			common.TenancyResourceName: {
				Usage: 25,
				Limit: 700,
			},
		},
	}

	dummyClusterModel3 := &common.HyperscalerGetResponse{
		Name: "dummy_name_3",
		UsageLimitMap: map[common.ResourceName]common.UsageLimit{
			common.TenancyResourceName: {
				Usage: 800,
				Limit: 900,
			},
		},
	}

	return []*common.HyperscalerGetResponse{
		dummyClusterModel1,
		dummyClusterModel2,
		dummyClusterModel3,
	}, nil
}

// GetCluster gets the required cluster for the client.
// Note: Implements models.HyperscalerClusterGetter interface on CVN V1 mock client.
// Receiver:
//	c: CVN V1 mock client pointer.
// Outputs:
//	- Required cluster response in models.HyperscalerGetResponse format.
//	- Error, if any.
func (c *v1MockClient) GetCluster(clusterName string) (*common.HyperscalerGetResponse, error) {
	return c.GetClusterWithContext(context.Background(), clusterName)
}

// GetClusterWithContext gets the required cluster for the client.
// Note: Implements models.HyperscalerClusterGetter interface on CVN V1 mock client.
// Receiver:
//	c: CVN V1 mock client pointer.
// Input:
//  ctx: context for the method
// Outputs:
//	- Required cluster response in models.HyperscalerGetResponse format.
//	- Error, if any.
func (c *v1MockClient) GetClusterWithContext(ctx context.Context, clusterName string) (*common.HyperscalerGetResponse, error) {
	return &common.HyperscalerGetResponse{
		Name: clusterName,
		UsageLimitMap: map[common.ResourceName]common.UsageLimit{
			common.TenancyResourceName: {
				Usage: 102,
				Limit: 500,
			},
		},
	}, nil
}
