// Copyright (c) 2020 NetApp, Inc. All rights reserved.

// authentication package provides following possible ways of authentication:
// 1. Using ASP .NET core project - azure authentication client see https://git.greenqloud.com/team-svl/azure-auth-client
// 2. Using Azure SDK for Go libraries.
package dotnet

import (
	"encoding/json"
)

// AuthServerResponse  represents the response received in response from the API server.
type AuthServerResponse struct {
	BearerToken string          `json:"bearerToken"`
	Exception   json.RawMessage `json:"exception"`
}

// unmarshalIntoAuthenticatorResponse de-serializes HTTP response from the .NET API into an instance of AuthServerResponse
// Input:
//	- responseBytes: Bytes in the HTTP response body.
// Output:
//	- An instance of AuthServerResponse representing response from API.
//	- Error, if any.
func unmarshalIntoAuthenticatorResponse(responseBytes []byte) (*AuthServerResponse, error) {
	var response = &AuthServerResponse{}
	err := json.Unmarshal(responseBytes, &response)
	if err != nil {
		return nil, err
	}

	return response, nil
}
