package factories

import (
	"fmt"
	"github.com/greenqloud/go-lib/log"
	"github.com/greenqloud/hyperscaler-network-client/authenticators/dotnet"
	"github.com/greenqloud/hyperscaler-network-client/authenticators/keyvault"
	"github.com/greenqloud/hyperscaler-network-client/authenticators/mock"
	"github.com/greenqloud/hyperscaler-network-client/models/azure"
	"github.com/greenqloud/hyperscaler-network-client/models/common"
	"time"
)

// CreateNewDRPAuthenticatorFromConfigOnly creates an common.Authenticator for DRP based on input configuration.
// Note: Use this method to infer common.AuthenticatorType from input configuration.
func CreateNewDRPAuthenticatorFromConfigOnly(config *azure.DRPConfiguration) (common.Authenticator, error) {
	if !config.ClientConfig.AuthenticationEnabled {
		return mock.NewTokenProviderWithMessage("authentication not enabled in environment"), nil
	}

	if config.AuthConfig == nil || config.Credentials == nil {
		msg := "authentication is enabled but nil values detected for AuthConfig and/or Azure credentials "
		log.Error(msg)
		return nil, fmt.Errorf(msg)
	}

	timeoutDuration := time.Duration(config.AuthConfig.TimeoutDuration) * time.Second

	var authenticator common.Authenticator = nil
	var err error = nil

	// Defaults to using go akv ff auth server url not set in configurations.
	if config.AuthConfig.AuthServerURL == "" {
		authenticator, err = keyvault.NewTokenProvider(config.Credentials, timeoutDuration)
	} else {
		authenticator = dotnet.NewAuthClient(config.Credentials, config.AuthConfig.AuthServerURL, timeoutDuration)
	}

	return authenticator, err
}
