// Copyright (c) 2020 NetApp, Inc. All rights reserved.

package common

// ConversionError indicates error in conversion from one type to another.
type ConversionError struct {
	message string
}

// ObjectNotFoundError indicates error when an object is expected but not retrieved.
type ObjectNotFoundError struct {
	message string
}

// BadRequestError bad request error struct
type BadRequestError struct {
	message string
}

// NotImplementedError type for indicating not implemented error.
type NotImplementedError struct {
	message string
}

// Error implements error interface on ConversionError type.
func (e *ConversionError) Error() string {
	return e.message
}

// Error implements error interface on ObjectNotFoundError type.
func (e *ObjectNotFoundError) Error() string {
	return e.message
}

// Error implements error interface on BadRequestError type.
func (e *BadRequestError) Error() string {
	return e.message
}

// Error implements error interface on NotImplementedError type.
func (e *NotImplementedError) Error() string {
	return e.message
}

func NewConversionError(message string) *ConversionError {
	return &ConversionError{message: message}
}

// NewDRPResponseConversionError creates a new ConversionError that represents error when converting
// response from DRP to standard response model.
func NewDRPResponseConversionError() *ConversionError {
	return &ConversionError{"error converting DRP response to standard hyperscaler cluster response model"}
}

// NewClusterNotFoundInNetworkError creates a new ObjectNotFoundError that represents error when the requested hyperscaler cluster
// is not found in request to the network.
func NewClusterNotFoundInNetworkError() *ObjectNotFoundError {
	return &ObjectNotFoundError{"requested cluster not found in the network."}
}

// NewNoHyperscalerClustersFoundInNetwork creates a new ObjectNotFoundError when no hyperscaler clusters are retrieved from the network.
func NewNoHyperscalerClustersFoundInNetwork() *ObjectNotFoundError {
	return &ObjectNotFoundError{"no hyperscaler clusters found in network."}
}

// NewBadRequestError returns a new BadRequestError with given message.
func NewBadRequestError(message string) *BadRequestError {
	return &BadRequestError{message}
}

// NewNotImplementedError returns a new NotImplementedError with given message.
func NewNotImplementedError(message string) *NotImplementedError {
	return &NotImplementedError{message: message}
}
