// Copyright (c) 2021 NetApp, Inc. All rights reserved.

package common

import (
	"sync"

	"github.com/greenqloud/go-lib/log"
	"github.com/caarlos0/env/v6"
)

// hyperscalerConfig type defines hyperscaler
// common configuration.
type hyperscalerConfig struct {
	LoadFromPatchFile bool   `env:"HYPERSCALER_CONFIG_LOAD_FROM_PATCH_FILE" envDefault:"false"`
	PatchFilename     string `env:"HYPERSCALER_CONFIG_PATCH_FILENAME" envDefault:"./patchClusters.yaml"`
}

var once sync.Once
var hsConfig hyperscalerConfig

// NewHyperscalerConfigFromEnv gets hyperscaler config from env
func NewHyperscalerConfigFromEnv() (*hyperscalerConfig, error) {
	var err error
	once.Do(func() {
		hsConfig = hyperscalerConfig{}
		err := env.Parse(&hsConfig)
		if err != nil {
			log.Errorf("Failed to get hyperscalerConfig env vars: %v", err)
		}
	})
	return &hsConfig, err
}
