package common

import "context"

// HyperscalerClusterGetter is the standard interface that defines methods
// to get cluster(s) from a network.
// Note: This interface *must* be implemented by any client of any hyperscaler cluster network.
type HyperscalerClusterGetter interface {
	// PreProcessClient
	// Note: PreProcessClient method signature can be updated to use generic key value pairs as input
	// to cover all kinds of pre-processing cases.
	PreProcessClient(regionName string)

	GetClusters() ([]*HyperscalerGetResponse, error)
	GetCluster(clusterName string) (*HyperscalerGetResponse, error)
	GetClustersWithContext(ctx context.Context) ([]*HyperscalerGetResponse, error)
	GetClusterWithContext(ctx context.Context, clusterName string) (*HyperscalerGetResponse, error)
}
